@@ -1,10 +1,12 @@
+from typing import Optional
+
 __all__ = ['ClientException', 'ValidationException']
 
 
 class ClientException(Exception):
     """Raised when the server does something we don't expect."""
 
-    def __init__(self, msg, item=None):
+    def __init__(self, msg: str, item: Optional[object] = None):
         if item is not None:
             msg = '%s: %r' % (msg, item)
         super().__init__(msg)
